Function arboreus_cts::simple_buffer_tree::center_of_mass
source · fn center_of_mass<C: PrimInt>(points: &Vec<Point<C>>) -> Point<C>Expand description
Compute the center of mass of a list of points.
fn center_of_mass<C: PrimInt>(points: &Vec<Point<C>>) -> Point<C>Compute the center of mass of a list of points.