pub trait SimpleClockTreeSpecification<N>where
N: NetlistBase,{
// Required methods
fn clock_net(&self) -> N::NetId;
fn target_skews(&self) -> HashMap<TerminalId<N>, f64>;
}Expand description
Specify a clock-tree by the clock source net and the target skews. This is used as input argument for clock-tree generator engines.
Required Methods
sourcefn clock_net(&self) -> N::NetId
fn clock_net(&self) -> N::NetId
Get clock net. The clock net must be connected to the clock source and to the clock sinks. The clock source node must be the only driving terminal on the clock net.
sourcefn target_skews(&self) -> HashMap<TerminalId<N>, f64>
fn target_skews(&self) -> HashMap<TerminalId<N>, f64>
Get the desired clock skews at the sink nodes. The sink nodes must all belong to the same net as the clock source.