Function arboreus_cts::simple_buffer_tree::find_clusters
source · fn find_clusters<C: PrimInt>(
points: &Vec<Point<C>>,
max_cluster_size: u32
) -> (Vec<u32>, u32)Expand description
Group points together to clusters and return a vector with the cluster ID for each point and the number of clusters.